@@ -15,6 +15,9 @@ var searchData=
   ['libevdev_5fevent_5ftype_5ffrom_5fname_5fn',['libevdev_event_type_from_name_n',['../group__misc.html#ga4ee03d650200bb04a23233570667fa84',1,'libevdev.h']]],
   ['libevdev_5fevent_5ftype_5fget_5fmax',['libevdev_event_type_get_max',['../group__misc.html#gabfad87ea78d034631cf3e5322ac383a1',1,'libevdev.h']]],
   ['libevdev_5fevent_5ftype_5fget_5fname',['libevdev_event_type_get_name',['../group__misc.html#gac99720fd926bf288764f9a81bf37ed09',1,'libevdev.h']]],
+  ['libevdev_5fevent_5fvalue_5ffrom_5fname',['libevdev_event_value_from_name',['../group__misc.html#ga314903beeafedabe45f879637e7254b0',1,'libevdev.h']]],
+  ['libevdev_5fevent_5fvalue_5ffrom_5fname_5fn',['libevdev_event_value_from_name_n',['../group__misc.html#gaebfc6b0ebb70169c9fec61620f1ea85f',1,'libevdev.h']]],
+  ['libevdev_5fevent_5fvalue_5fget_5fname',['libevdev_event_value_get_name',['../group__misc.html#gabcd45c5e963cba245e944ea66e72fcc3',1,'libevdev.h']]],
   ['libevdev_5ffetch_5fevent_5fvalue',['libevdev_fetch_event_value',['../group__bits.html#ga0a7be80d769294bf9758adf79c3c7147',1,'libevdev.h']]],
   ['libevdev_5ffetch_5fslot_5fvalue',['libevdev_fetch_slot_value',['../group__mt.html#gaca19dca5aa8f0ea3b210f3fc670384ec',1,'libevdev.h']]],
   ['libevdev_5ffree',['libevdev_free',['../group__init.html#gacd9fe760d15be25fc99ce469034bd78c',1,'libevdev.h']]],
