@@ -525,7 +525,8 @@ libevdev_get_fd(const struct libevdev* dev)
 static inline void
 init_event(struct libevdev *dev, struct input_event *ev, int type, int code, int value)
 {
-	ev->time = dev->last_event_time;
+	ev->input_event_sec = dev->last_event_time.tv_sec;
+	ev->input_event_usec = dev->last_event_time.tv_usec;
 	ev->type = type;
 	ev->code = code;
 	ev->value = value;
@@ -967,7 +968,8 @@ update_state(struct libevdev *dev, const struct input_event *e)
 			break;
 	}
 
-	dev->last_event_time = e->time;
+	dev->last_event_time.tv_sec = e->input_event_sec;
+	dev->last_event_time.tv_usec = e->input_event_usec;
 
 	return rc;
 }
@@ -1611,6 +1613,23 @@ libevdev_event_code_get_name(unsigned int type, unsigned int code)
 	return event_type_map[type][code];
 }
 
+LIBEVDEV_EXPORT const char *
+libevdev_event_value_get_name(unsigned int type,
+			      unsigned int code,
+			      int value)
+{
+	/* This is a simplified version because nothing else
+	   is an enum like ABS_MT_TOOL_TYPE so we don't need
+	   a generic lookup */
+	if (type != EV_ABS || code != ABS_MT_TOOL_TYPE)
+		return NULL;
+
+	if (value > MT_TOOL_MAX)
+		return NULL;
+
+	return mt_tool_map[value];
+}
+
 LIBEVDEV_EXPORT const char*
 libevdev_property_get_name(unsigned int prop)
 {
