@@ -39,8 +39,14 @@ extern "C" {
  * the \ref ioctls through type-safe interfaces and provides functions to change
  * the appearance of the device.
  *
+ * Development
+ * ===========
+ * The git repository is available here:
+ *
+ *   - https://gitlab.freedesktop.org/libevdev/libevdev
+ *
  * Development of libevdev is discussed on
- * [input-tools@lists.freedesktop.org](http://lists.freedesktop.org/mailman/listinfo/input-tools)
+ * [input-tools@lists.freedesktop.org](http://lists.freedesktop.org/mailman/listinfo/input-tools).
  * Please submit patches, questions or general comments there.
  *
  * Handling events and SYN_DROPPED
@@ -142,7 +148,7 @@ extern "C" {
  * @endcode
  *
  * A more complete example is available with the libevdev-events tool here:
- * http://cgit.freedesktop.org/libevdev/tree/tools/libevdev-events.c
+ * https://gitlab.freedesktop.org/libevdev/libevdev/blob/master/tools/libevdev-events.c
  *
  * Backwards compatibility with older kernel
  * =========================================
@@ -157,8 +163,8 @@ extern "C" {
  *
  * Reporting bugs
  * ==============
- * Please report bugs in the freedesktop.org bugzilla under the libevdev product:
- * https://bugs.freedesktop.org/enter_bug.cgi?product=libevdev
+ * Please report bugs in the freedesktop.org GitLab:
+ * https://gitlab.freedesktop.org/libevdev/libevdev/issues/
  */
 
 /**
@@ -956,6 +962,10 @@ enum libevdev_grab_mode {
  * Grabbing an already grabbed device, or ungrabbing an ungrabbed device is
  * a noop and always succeeds.
  *
+ * A grab is an operation tied to a file descriptor, not a device. If a
+ * client changes the file descriptor with libevdev_change_fd(), it must
+ * also re-issue a grab with libevdev_grab().
+ *
  * @param dev The evdev device, already initialized with libevdev_set_fd()
  * @param grab If true, grab the device. Otherwise ungrab the device.
  *
@@ -1024,6 +1034,9 @@ int libevdev_set_fd(struct libevdev* dev, int fd);
  *
  * The fd may be open in O_RDONLY or O_RDWR.
  *
+ * After changing the fd, the device is assumed ungrabbed and a caller must
+ * call libevdev_grab() again.
+ *
  * It is an error to call this function before calling libevdev_set_fd().
  *
  * @param dev The evdev device, already initialized with libevdev_set_fd()
@@ -2006,6 +2019,29 @@ const char * libevdev_event_type_get_name(unsigned int type);
  */
 const char * libevdev_event_code_get_name(unsigned int type, unsigned int code);
 
+/**
+ * @ingroup misc
+ *
+ * This function resolves the event value for a code.
+ *
+ * For almost all event codes this will return NULL as the value is just a
+ * numerical value. As of kernel 4.17, the only event code that will return
+ * a non-NULL value is EV_ABS/ABS_MT_TOOL_TYPE.
+ *
+ * @param type The event type for the value to query (EV_ABS, etc.)
+ * @param code The event code for the value to query (e.g. ABS_MT_TOOL_TYPE)
+ * @param value The event value to return the name for (e.g. MT_TOOL_PALM)
+ *
+ * @return The name of the given event value (e.g. MT_TOOL_PALM) or NULL for
+ * an invalid type or code or NULL for an axis that has numerical values
+ * only.
+ *
+ * @note The list of names is compiled into libevdev. If the kernel adds new
+ * defines for new event values, libevdev will not automatically pick these up.
+ */
+const char * libevdev_event_value_get_name(unsigned int type,
+					   unsigned int code,
+					   int value);
 /**
  * @ingroup misc
  *
@@ -2114,6 +2150,56 @@ int libevdev_event_code_from_name(unsigned int type, const char *name);
 int libevdev_event_code_from_name_n(unsigned int type, const char *name,
 				    size_t len);
 
+/**
+ * @ingroup misc
+ *
+ * Look up an event value by its type, code and name. Event values start
+ * with a fixed prefix followed by their name (eg., "MT_TOOL_PALM"). The
+ * prefix must be included in the name. It returns the constant assigned
+ * to the event code or -1 if not found.
+ *
+ * You have to pass the event type and code where to look for the name. For
+ * instance, to resolve "MT_TOOL_PALM" you need to pass EV_ABS as type,
+ * ABS_MT_TOOL_TYPE as code and "MT_TOOL_PALM" as string.
+ *
+ * As of kernel 4.17, only EV_ABS/ABS_MT_TOOL_TYPE support name resolution.
+ *
+ * @param type The event type (EV_* constant) where to look for the name.
+ * @param code The event code (ABS_* constant) where to look for the name.
+ * @param name A non-NULL string describing an input-event value
+ * ("MT_TOOL_TYPE", ...)
+ *
+ * @return The given value constant for the name or -1 if not found.
+ */
+int libevdev_event_value_from_name(unsigned int type, unsigned int code,
+				   const char *name);
+
+/**
+ * @ingroup misc
+ *
+ * Look up an event value by its type, code and name. Event values start
+ * with a fixed prefix followed by their name (eg., "MT_TOOL_PALM"). The
+ * prefix must be included in the name. It returns the constant assigned
+ * to the event code or -1 if not found.
+ *
+ * You have to pass the event type and code where to look for the name. For
+ * instance, to resolve "MT_TOOL_PALM" you need to pass EV_ABS as type,
+ * ABS_MT_TOOL_TYPE as code and "MT_TOOL_PALM" as string.
+ *
+ * As of kernel 4.17, only EV_ABS/ABS_MT_TOOL_TYPE support name resolution.
+ *
+ * @param type The event type (EV_* constant) where to look for the name.
+ * @param code The event code (ABS_* constant) where to look for the name.
+ * @param name A non-NULL string describing an input-event value
+ * ("MT_TOOL_TYPE", ...)
+ * @param len The length of the string in @p name excluding any terminating 0
+ * character.
+ *
+ * @return The given value constant for the name or -1 if not found.
+ */
+int libevdev_event_value_from_name_n(unsigned int type, unsigned int code,
+				     const char *name, size_t len);
+
 /**
  * @ingroup misc
  *
