@@ -22,12 +22,34 @@
 
 #include <config.h>
 #include <libevdev/libevdev.h>
+#include <stdbool.h>
 
 #include <check.h>
 
 #ifndef _TEST_COMMON_H_
 #define _TEST_COMMON_H_
 
+struct libevdev_test {
+	const char *name;
+	Suite* (*setup)(void);
+	bool needs_root_privileges;
+} __attribute__((aligned(16)));
+
+#define _TEST_SUITE(name, root_privs) \
+	static Suite* (name##_setup)(void); \
+	static const struct libevdev_test _test \
+	__attribute__((used)) \
+	__attribute__((section ("test_section"))) = { \
+		#name, name##_setup, root_privs \
+	}; \
+	static Suite* (name##_setup)(void)
+
+#define TEST_SUITE(name) \
+	_TEST_SUITE(name, false)
+
+#define TEST_SUITE_ROOT_PRIVILEGES(name) \
+	_TEST_SUITE(name, true)
+
 #define TEST_DEVICE_NAME "libevdev test device"
 
 #include "test-common-uinput.h"
