@@ -22,24 +22,19 @@
 
 #include <config.h>
 #include <check.h>
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <sys/ptrace.h>
 #include <sys/resource.h>
 #include <sys/wait.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <libevdev/libevdev.h>
 
 #include "test-common.h"
 
-extern Suite *event_name_suite(void);
-extern Suite *event_code_suite(void);
-extern Suite *libevdev_init_test(void);
-extern Suite *queue_suite(void);
-extern Suite *libevdev_has_event_test(void);
-extern Suite *libevdev_events(void);
-extern Suite *uinput_suite(void);
-
 static int
 is_debugger_attached(void)
 {
@@ -68,14 +63,48 @@ is_debugger_attached(void)
 	return rc;
 }
 
+static bool
+device_nodes_exist(void)
+{
+	struct stat st;
+	int rc;
+
+	rc = stat("/dev/uinput", &st);
+	if (rc == -1 && errno == ENOENT)
+		return false;
+
+	rc = stat("/dev/input", &st);
+	if (rc == -1 && errno == ENOENT)
+		return false;
+
+	/* Any issues but ENOENT we just let the test suite blow up later */
+	return true;
+}
+
+extern const struct libevdev_test __start_test_section, __stop_test_section;
+
 int main(void)
 {
+	const struct libevdev_test *t;
 	const struct rlimit corelimit = {0, 0};
 	int failed;
 
-	if (getuid() != 0) {
-		fprintf(stderr, "This test needs to run as root\n");
-		return 77;
+	for (t = &__start_test_section; t < &__stop_test_section; t++) {
+		if (t->needs_root_privileges) {
+			if (getenv("LIBEVDEV_SKIP_ROOT_TESTS"))
+				return 77;
+
+			if (getuid() != 0) {
+				fprintf(stderr, "This test needs to run as root\n");
+				return 77;
+			}
+			if (!device_nodes_exist()) {
+				fprintf(stderr, "This test needs /dev/input and /dev/uinput to exist\n");
+				return 77;
+			}
+
+			break;
+		}
 	}
 
 	if (is_debugger_attached())
@@ -86,14 +115,11 @@ int main(void)
 
 	libevdev_set_log_function(test_logfunc_abort_on_error, NULL);
 
-	Suite *s = libevdev_has_event_test();
-	SRunner *sr = srunner_create(s);
-	srunner_add_suite(sr, libevdev_events());
-	srunner_add_suite(sr, libevdev_init_test());
-	srunner_add_suite(sr, queue_suite());
-	srunner_add_suite(sr, event_name_suite());
-	srunner_add_suite(sr, event_code_suite());
-	srunner_add_suite(sr, uinput_suite());
+	SRunner *sr = srunner_create(NULL);
+	for (t = &__start_test_section; t < &__stop_test_section; t++) {
+		srunner_add_suite(sr, t->setup());
+	}
+
 	srunner_run_all(sr, CK_NORMAL);
 
 	failed = srunner_ntests_failed(sr);
